from argparse import ArgumentParser

from dodo_commands import Dodo
from dodo_commands.framework.global_config import load_global_config_parser


def _args():
    parser = ArgumentParser(description="")

    # Parse the arguments.
    args = Dodo.parse_args(parser)

    args.file_browser = load_global_config_parser().get("settings", "file_browser")
    args.project_dir = Dodo.get("/ROOT/project_dir")

    return args


# Use safe=False if the script makes changes other than through Dodo.run
if Dodo.is_main(__name__, safe=True):
    args = _args()
    Dodo.run([args.file_browser, args.project_dir])



import os
from argparse import ArgumentParser

from dodo_commands import Dodo


def _args():
    parser = ArgumentParser(
        description=(
            "Writes (or removes) a small script that activates the latest "
            + "Dodo Commands project"
        )
    )
    parser.add_argument("status", choices=["on", "off"])
    return Dodo.parse_args(parser)


if Dodo.is_main(__name__, safe=False):
    args = _args()

    for shell, activate_cmd in (
        ("bash", "$(dodo env --latest --shell=bash) &&"),
        ("fish", "eval (dodo env --latest --shell=fish); and"),
    ):

        confd_dir = os.path.expanduser("~/.config/%s/conf.d" % shell)
        if not os.path.exists(confd_dir):
            Dodo.run(["mkdir", "-p", confd_dir])
        script = os.path.join(confd_dir, "dodo_autostart." + shell)
        if args.status == "on" and not os.path.exists(script):
            with open(script, "w") as f:
                f.write("# NOTE: automatically generated file, don't edit.\n")
                f.write("%s dodo check-version --dodo --config\n" % activate_cmd)
        if args.status == "off" and os.path.exists(script):
            os.unlink(script)



import os

from dodo_commands import Dodo
from dodo_commands.dependencies.get import plumbum
from dodo_commands.framework.config import expand_keys


def _args():
    Dodo.parser.description = "Run docker compose"

    Dodo.parser.add_argument("compose_args", nargs="*")
    Dodo.parser.add_argument("--detach", action="store_true")
    Dodo.parser.add_argument("--dev", action="store_true")
    Dodo.parser.add_argument("--print", action="store_true")
    args = Dodo.parse_args()

    key = "DOCKER_COMPOSE" + ("_DEV" if args.dev else "")
    args.cwd = Dodo.get("/" + key + "/cwd")
    args.files = Dodo.get("/" + key + "/files", None)
    args.map = Dodo.get("/" + key + "/map", {})
    args.compose_project_name = Dodo.get(
        "/" + key + "/compose_project_name", Dodo.get("/ROOT/env_name")
    )
    return args


# Use safe=False if the script makes changes other than through Dodo.run
if Dodo.is_main(__name__, safe=True):
    args = _args()

    for src, dest in args.map.items():
        with open(src) as ifs:
            content = expand_keys(Dodo.get(), ifs.read())
        with open(dest, "w") as ofs:
            ofs.write(content)

    def get_file_args():
        result = []
        for f in args.files:
            result.extend(["--file", f])
        return result

    file_args = get_file_args() if args.files else []
    detach_args = ["--detach"] if args.detach else []

    if args.print:
        for f in args.files:
            print(os.path.abspath(f))
            Dodo.run(["cat", f], cwd=args.cwd)
    else:
        with plumbum.local.env(COMPOSE_PROJECT_NAME=args.compose_project_name):
            Dodo.run(
                ["docker-compose", *file_args, *args.compose_args, *detach_args],
                cwd=args.cwd,
            )



"""Pull the latest version of the Dodo Commands system."""
import glob
import os
import sys
from argparse import ArgumentParser

from dodo_commands import CommandError, Dodo
from dodo_commands.framework.config_io import ConfigIO
from dodo_commands.framework.paths import Paths
from dodo_commands.framework.util import query_yes_no, symlink


def _args():
    parser = ArgumentParser()
    parser.add_argument(
        "src_dir", help="The src directory for the bootstrapped project"
    )
    parser.add_argument(
        "shared_config_dir",
        help="Location relative to src_dir where the shared project config is stored",
    )
    parser.add_argument("--force", dest="use_force", action="store_true")

    group = parser.add_mutually_exclusive_group()
    group.add_argument(
        "--git-url",
        dest="git_url",
        help="Clone this repository to the src_dir location",
    )
    group.add_argument(
        "--link-dir",
        help="Make the src directory a symlink to this directory",
    )
    group.add_argument(
        "--cookiecutter-url",
        help="Use cookiecutter to create the src_dir location",
    )

    parser.add_argument(
        "--depth", type=int, default=0, help="Depth for cloning repositories"
    )
    parser.add_argument("--branch", help="Branch to checkout after cloning")

    parser.add_argument(
        "--src-subdir",
        help="Specify a subdirectory of src_dir to clone into",
    )

    args = Dodo.parse_args(parser)
    args.project_dir = Dodo.get("/ROOT/project_dir")
    return args


def _report(msg):
    sys.stderr.write(msg + "\n")


def _copy_defaults(args, shared_config_dir):
    config_dir = os.path.join(args.project_dir, ".dodo_commands")
    has_printed_header = False

    for filename in glob.glob(os.path.join(shared_config_dir, "*")):
        dest_path = os.path.join(config_dir, os.path.basename(filename))
        if os.path.exists(dest_path):
            if args.confirm:
                if not has_printed_header:
                    has_printed_header = True
                    print(
                        "\nCopying shared environment files to your local environment...\n"
                    )
                print(
                    "Warning, destination path already exists: %s. Overwrite it?"
                    % dest_path
                )
            elif args.use_force:
                print("Overwriting existing path: %s" % dest_path)
            else:
                raise CommandError(
                    "Destination path %s already exists. " % dest_path
                    + "Use the --confirm or --force flag to overwrite it."
                )
        Dodo.run(["cp", "-rf", filename, dest_path])


def _clone(args, src_dir):
    if os.path.exists(src_dir):
        raise CommandError("Cannot clone into %s, path already exists" % src_dir)

    Dodo.run(
        ["git", "clone", args.git_url, os.path.basename(src_dir)]
        + (["--depth", args.depth] if args.depth else []),
        cwd=os.path.dirname(src_dir),
    )
    if args.branch:
        Dodo.run(["git", "checkout", args.branch], cwd=src_dir)


def _cookiecutter(src_dir, cookiecutter_url):
    if os.path.exists(src_dir):
        raise CommandError("Cannot clone into %s, path already exists" % src_dir)

    Dodo.run(["cookiecutter", cookiecutter_url, "-o", src_dir])


def _link_dir(link_target, link_name):
    if os.path.exists(link_name):
        raise CommandError("Cannot create a link because %s already exists" % link_name)
    Dodo.run(["ln", "-s", link_target, link_name])


def _get_full_src_dir(src_dir, src_subdir):
    postfix = os.path.join(src_dir, src_subdir) if src_subdir else src_dir
    return (
        postfix
        if os.path.isabs(src_dir)
        else os.path.abspath(os.path.join(args.project_dir, postfix))
    )


if Dodo.is_main(__name__, safe=True):
    args = _args()

    full_src_dir = _get_full_src_dir(args.src_dir, args.src_subdir)
    Dodo.run(["mkdir", "-p", os.path.dirname(full_src_dir)])

    if args.git_url:
        _clone(args, full_src_dir)
    elif args.link_dir:
        _link_dir(os.path.expanduser(args.link_dir), full_src_dir)
    elif args.cookiecutter_url:
        _cookiecutter(full_src_dir, os.path.expanduser(args.cookiecutter_url))

    shared_config_dir = os.path.join(full_src_dir, args.shared_config_dir)
    _copy_defaults(args, shared_config_dir)
